module Sociable
  extend ActiveSupport::Concern

  included do
    has_many :views, as: :viewable, dependent: :destroy
    has_many :downloads, as: :downloadable, dependent: :destroy
    has_many :likes, as: :likeable, dependent: :destroy
    has_many :shares, as: :shareable, dependent: :destroy
  end

  def liked?(user)
    !likes.where(user: user).blank?
  end

  def like(user)
    Like.create(user: user, likeable: self)
  end

  def dislike(user)
    Like.where(user: user, likeable: self).destroy_all
  end

  def download(user)
    Download.create(user: user, downloadable: self)
  end

end
