class TopicsImporter
  def initialize(items)
    @items = items
    @topics = {}
    @topics_relations = { objects: [], index: {} }
  end

  def import
    learning_objects = []

    @items.each do |learning_object|
      lo_topics = parse_topics(learning_object.get_metadata_values_of 'dc.subject.category')

      lo_topics.each do |topic_name|
        topic = @topics[topic_name]

        if !topic_exists? topic_name
          topic = Topic.where(name: topic_name).new
        elsif @topics[topic_name].nil?
          topic = Topic.find_by_name topic_name
        end

        create_relations(topic_name)
        learning_object.topics << topic
        @topics[topic_name] = topic
      end
      learning_objects << learning_object
      separate_relations
    end

    Topic.import @topics.values
    LearningObject.import learning_objects
    import_topics_relations
  end

  private

  def create_relations(topic_name)
    @topics_relations[:objects] << topic_name
  end

  def separate_relations
    @topics_relations[:objects].push nil
  end

  def import_topics_relations
    relations = []

    @topics_relations[:objects].each_with_index do |relation, i|
      next if relation.nil? || @topics_relations[:objects][i - 1].nil?

      parent_id = Topic.find_by_name(@topics_relations[:objects][i - 1]).id
      child_id = Topic.find_by_name(relation).id

      @topics_relations[:index][parent_id] = [] if @topics_relations[:index][parent_id].nil?

      next if @topics_relations[:index][parent_id].include?(child_id)

      @topics_relations[:index][parent_id] << child_id

      next if TopicRelationship.exists?(parent_id: parent_id, child_id: child_id)

      relations.push TopicRelationship.where(parent_id: parent_id, child_id: child_id).new
    end

    TopicRelationship.import relations
  end

  def parse_topics(values)
    topics = []
    values.compact!
    values.each do |value|
      topics = value.split('::')
    end
    topics.map(&:strip)
  end

  def topic_exists?(topic_name)
    Topic.exists? name: topic_name || !@topics[topic_name].nil?
  end
end
