# == Schema Information
#
# Table name: collections
#
#  id                     :integer          not null, primary key
#  name                   :string
#  description            :text
#  privacy                :string           default("private")
#  owner_id               :integer
#  owner_type             :string
#  created_at             :datetime         not null
#  updated_at             :datetime         not null
#  views_count            :integer          default("0")
#  downloads_count        :integer          default("0")
#  likes_count            :integer          default("0")
#  shares_count           :integer          default("0")
#  score                  :float            default("0.0")
#  follows_count          :integer          default("0")
#  thumbnail_file_name    :string
#  thumbnail_content_type :string
#  thumbnail_file_size    :integer
#  thumbnail_updated_at   :datetime
#

require 'test_helper'

class CollectionTest < ActiveSupport::TestCase
  should have_many :collection_items
  should have_many(:collections).through(:collection_items).source(:collectionable)
  should have_many(:learning_objects).through(:collection_items).source(:collectionable)

  should belong_to :owner

  should validate_presence_of(:name)
  should validate_presence_of(:owner)
  should validate_inclusion_of(:privacy).in_array(%w(public private)).with_message('Privacy must be public or private')
end
